==> jm_basic_flutter-1.0.3.tar.gz: lib/widgets/options_select_button.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_conditional_rendering/flutter_conditional_rendering.dart';

class OptionsSelectButton extends StatelessWidget {
  final String title;
  final VoidCallback? onPressed;
  final bool isEnabled;
  final bool isRightArrowNeeded;
  final Color borderColor;
  final String hint;
  final bool errorBorder;

  const OptionsSelectButton({
    this.title = '',
    this.onPressed,
    this.isEnabled = true,
    this.isRightArrowNeeded = true,
    this.borderColor = const Color(0xFFCCCCCC),
    this.hint = '',
    this.errorBorder = false,
  });

  @override
  Widget build(BuildContext context) {
    Color background = isEnabled ? Colors.white : Color(0xFFF5F5F5);
    bool textEmpty = title == null || title.isEmpty;
    return RawMaterialButton(
      onPressed: isEnabled ? onPressed : null,
      constraints: BoxConstraints(),
      shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(4)),
      fillColor: background,
      elevation: 0,
      child: Container(
        height: 38,
        padding: EdgeInsets.symmetric(horizontal: 12),
        decoration: BoxDecoration(borderRadius: BorderRadius.circular(4), border: Border.all(color: getBorderColor())),
        child: Row(
          children: [
            Flexible(
                child: Text(
              textEmpty ? hint : title,
              overflow: TextOverflow.ellipsis,
              style: TextStyle(color: getColor(), fontSize: 13, fontWeight: FontWeight.w500),
            )),
            Conditional.single(
                context: context,
                conditionBuilder: (_) => isRightArrowNeeded,
                widgetBuilder: (_) => Icon(
                      Icons.keyboard_arrow_down_outlined,
                      size: 24,
                      color: Color(0xFF777777),
                    ),
                fallbackBuilder: (_) => SizedBox())
          ],
          crossAxisAlignment: CrossAxisAlignment.center,
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
        ),
      ),
    );
  }

  Color getColor() {
    if (title == null || title.isEmpty) {
      return Color(0xFFA1A1A1);
    } else {
      return Color(0xFF222222);
    }
  }

  Color getBorderColor() {
    if (errorBorder) {
      return Color(0xFFE53225);
    }
    return borderColor;
  }
}

==> jm_basic_flutter-1.0.4.tar.gz: lib/widgets/options_select_button.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_conditional_rendering/flutter_conditional_rendering.dart';

class OptionsSelectButton extends StatelessWidget {
  final String title;
  final VoidCallback? onPressed;
  final bool isEnabled;
  final bool isRightArrowNeeded;
  final Color borderColor;
  final String hint;
  final bool errorBorder;

  const OptionsSelectButton({
    this.title = '',
    this.onPressed,
    this.isEnabled = true,
    this.isRightArrowNeeded = true,
    this.borderColor = const Color(0xFFCCCCCC),
    this.hint = '',
    this.errorBorder = false,
  });

  @override
  Widget build(BuildContext context) {
    Color background = isEnabled ? Colors.white : Color(0xFFF5F5F5);
    bool textEmpty = title.isEmpty;
    return RawMaterialButton(
      onPressed: isEnabled ? onPressed : null,
      constraints: BoxConstraints(),
      shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(4)),
      fillColor: background,
      elevation: 0,
      child: Container(
        height: 38,
        padding: EdgeInsets.symmetric(horizontal: 12),
        decoration: BoxDecoration(borderRadius: BorderRadius.circular(4), border: Border.all(color: getBorderColor())),
        child: Row(
          children: [
            Flexible(
                child: Text(
              textEmpty ? hint : title,
              overflow: TextOverflow.ellipsis,
              style: TextStyle(color: getColor(), fontSize: 13, fontWeight: FontWeight.w500),
            )),
            Conditional.single(
                context: context,
                conditionBuilder: (_) => isRightArrowNeeded,
                widgetBuilder: (_) => Icon(
                      Icons.keyboard_arrow_down_outlined,
                      size: 24,
                      color: Color(0xFF777777),
                    ),
                fallbackBuilder: (_) => SizedBox())
          ],
          crossAxisAlignment: CrossAxisAlignment.center,
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
        ),
      ),
    );
  }

  Color getColor() {
    if (title.isEmpty) {
      return Color(0xFFA1A1A1);
    } else {
      return Color(0xFF222222);
    }
  }

  Color getBorderColor() {
    if (errorBorder) {
      return Color(0xFFE53225);
    }
    return borderColor;
  }
}
